summaryrefslogtreecommitdiffstats
path: root/ui/gfx/gtk_util.h
diff options
context:
space:
mode:
Diffstat (limited to 'ui/gfx/gtk_util.h')
-rw-r--r--ui/gfx/gtk_util.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/ui/gfx/gtk_util.h b/ui/gfx/gtk_util.h
index 52d2bc4..323f1df 100644
--- a/ui/gfx/gtk_util.h
+++ b/ui/gfx/gtk_util.h
@@ -21,10 +21,11 @@ namespace gfx {
class Rect;
// Call gtk_init() using the argc and argv from command_line.
// gtk_init() wants an argc and argv that it can mutate; we provide those,
// but leave the original CommandLine unaltered.
UI_EXPORT void GtkInitFromCommandLine(const CommandLine& command_line);
+UI_EXPORT void GdkInitFromCommandLine(const CommandLine& command_line);
// Convert and copy a SkBitmap to a GdkPixbuf. NOTE: this uses BGRAToRGBA, so
// it is an expensive operation. The returned GdkPixbuf will have a refcount of
@@ -21,10 +21,11 @@ namespace gfx {
class Rect;
-// Call gtk_init() using the argc and argv from command_line.
-// gtk_init() wants an argc and argv that it can mutate; we provide those,
-// but leave the original CommandLine unaltered.
+// Call gtk_init() / gdk_init() using the argc and argv from command_line.
+// These init functions want an argc and argv that they can mutate; we provide
+// those, but leave the original CommandLine unaltered.
UI_EXPORT void GtkInitFromCommandLine(const CommandLine& command_line);